@@ -3,22 +3,22 @@
 /*			   NOTICE
  *
  * Copyright (c) 1990,1992,1993 Britt Yenne.  All rights reserved.
- * 
+ *
  * This software is provided AS-IS.  The author gives no warranty,
- * real or assumed, and takes no responsibility whatsoever for any 
+ * real or assumed, and takes no responsibility whatsoever for any
  * use or misuse of this software, or any damage created by its use
  * or misuse.
- * 
+ *
  * This software may be freely copied and distributed provided that
  * no part of this NOTICE is deleted or edited in any manner.
- * 
+ *
  */
 
-/* Mail comments or questions to metawire.org */
 
 #include "header.h"
 #include "socket.h"
 #include "menu.h"
+#include "mem.h"
 
 #ifdef HAVE_IOVEC_H
 # include <iovec.h>
@@ -105,7 +105,7 @@ send_oob(fd, ptr, len)
 
     if((r = writev(fd, iov, 3)) != len + 2)
     {
-    	if (r >= 0 || (errno != EPIPE && errno != ECONNRESET))
+	if (r >= 0 || (errno != EPIPE && errno != ECONNRESET))
 	  show_error("send_oob: write failed");
     }
 }
@@ -122,15 +122,15 @@ send_import(to, from)
 	v3p.code = V3_IMPORT;
 	v3p.host_addr = htonl(from->host_addr);
 	v3p.pid = htonl(from->remote.pid);
-	strncpy(v3p.name, from->user_name, V3_NAMELEN);
-	strncpy(v3p.host, from->host_fqdn, V3_HOSTLEN);
+	(void)strncpy(v3p.name, from->user_name, V3_NAMELEN);
+	(void)strncpy(v3p.host, from->host_fqdn, V3_HOSTLEN);
 	send_oob(to->fd, &v3p, V3_PACKLEN);
     }
     else if(to->remote.vmajor == 2)
     {
 	v2p.code = V2_IMPORT;
-	strncpy(v2p.name, from->user_name, V2_NAMELEN);
-	strncpy(v2p.host, from->host_fqdn, V2_HOSTLEN);
+	(void)strncpy(v2p.name, from->user_name, V2_NAMELEN);
+	(void)strncpy(v2p.host, from->host_fqdn, V2_HOSTLEN);
 	(void)write(to->fd, &v2p, V2_PACKLEN);
     }
 }
@@ -146,15 +146,15 @@ send_accept(to, from)
 	v3p.code = V3_ACCEPT;
 	v3p.host_addr = htonl(from->host_addr);
 	v3p.pid = htonl(from->remote.pid);
-	strncpy(v3p.name, from->user_name, V3_NAMELEN);
-	strncpy(v3p.host, from->host_fqdn, V3_HOSTLEN);
+	(void)strncpy(v3p.name, from->user_name, V3_NAMELEN);
+	(void)strncpy(v3p.host, from->host_fqdn, V3_HOSTLEN);
 	send_oob(to->fd, &v3p, V3_PACKLEN);
     }
     else if(to->remote.vmajor == 2)
     {
 	v2p.code = V2_ACCEPT;
-	strncpy(v2p.name, from->user_name, V2_NAMELEN);
-	strncpy(v2p.host, from->host_fqdn, V2_HOSTLEN);
+	(void)strncpy(v2p.name, from->user_name, V2_NAMELEN);
+	(void)strncpy(v2p.host, from->host_fqdn, V2_HOSTLEN);
 	(void)write(to->fd, &v2p, V2_PACKLEN);
     }
 }
@@ -175,14 +175,14 @@ v2_process(user, pack)
     /* Ytalk version 2.* didn't have very clever import/export
      * capabilities.  We'll just go with the flow.
      */
-    strncpy(name, pack->name, V2_NAMELEN);
-    strncpy(host, pack->host, V2_HOSTLEN);
+    (void)strncpy(name, pack->name, V2_NAMELEN);
+    (void)strncpy(host, pack->host, V2_HOSTLEN);
     name[V2_NAMELEN] = '\0';
     host[V2_HOSTLEN] = '\0';
     if((host_addr = get_host_addr(host)) == (ylong)-1)
     {
 	errno = 0;
-	sprintf(errstr, "unknown host: '%s'", host);
+	(void)sprintf(errstr, "unknown host: '%s'", host);
 	show_error(errstr);
 	show_error("port from ytalk V2.? failed");
 	return;
@@ -197,15 +197,15 @@ v2_process(user, pack)
 		break;
 	    if(!(def_flags & FL_IMPORT))
 	    {
-		sprintf(estr, "Import %s@%s?", name, host);
+		(void)sprintf(estr, "Import %s@%s?", name, host);
 		if(yes_no(estr) == 'n')
 		    break;
 	    }
 
 	    /* invite him but don't ring him */
 
-	    sprintf(estr, "%s@%s", name, host);
-	    invite(estr, 0);
+	    (void)sprintf(estr, "%s@%s", name, host);
+	    (void)invite(estr, 0);
 
 	    /* now tell him to connect to us */
 
@@ -223,8 +223,8 @@ v2_process(user, pack)
 	    send_accept(u, user);
 	    break;
 	case V2_ACCEPT:
-	    sprintf(estr, "%s@%s", name, host);
-	    invite(estr, 1);	/* we should be expected */
+	    (void)sprintf(estr, "%s@%s", name, host);
+	    (void)invite(estr, 1);	/* we should be expected */
 	    break;
     }
 }
@@ -242,8 +242,8 @@ v3_process_pack(user, pack)
     static char host[V3_HOSTLEN + 1];
     static char estr[V3_NAMELEN + V3_HOSTLEN + 20];
 
-    strncpy(name, pack->name, V3_NAMELEN);
-    strncpy(host, pack->host, V3_HOSTLEN);
+    (void)strncpy(name, pack->name, V3_NAMELEN);
+    (void)strncpy(host, pack->host, V3_HOSTLEN);
     name[V3_NAMELEN] = '\0';
     host[V3_HOSTLEN] = '\0';
     if((host_addr = get_host_addr(host)) == (ylong)-1)
@@ -261,20 +261,20 @@ v3_process_pack(user, pack)
 		break;
 	    if(!(def_flags & FL_IMPORT))
 	    {
-		sprintf(estr, "Import %s@%s?", name, host);
+		(void)sprintf(estr, "Import %s@%s?", name, host);
 		if(yes_no(estr) == 'n')
 		    break;
 	    }
 
 	    /* invite him but don't ring him */
 
-	    sprintf(estr, "%s@%s", name, host);
+	    (void)sprintf(estr, "%s@%s", name, host);
 	    u2 = invite(estr, 0);
 
 	    /* fix the pid, so that two quick V3_IMPORT requests of the
 	     * same user still get caught  -roger
 	     */
-	    if (u2 != NULL && strcmp(u2->user_name, name) == 0 && 
+	    if (u2 != NULL && strcmp(u2->user_name, name) == 0 &&
 	        host_addr == u2->host_addr) {
 	      u2->remote.pid = pid;
 	    }
@@ -295,8 +295,8 @@ v3_process_pack(user, pack)
 	    send_accept(u, user);
 	    break;
 	case V3_ACCEPT:
-	    sprintf(estr, "%s@%s", name, host);
-	    invite(estr, 1);	/* we should be expected */
+	    (void)sprintf(estr, "%s@%s", name, host);
+	    (void)invite(estr, 1);	/* we should be expected */
 	    break;
     }
 }
@@ -509,7 +509,7 @@ read_user(fd)
 		    if(write(user->output_fd, buf, p - buf) <= 0)
 		    {
 			show_error("write to user output file failed");
-			close(user->output_fd);
+			(void)close(user->output_fd);
 			user->output_fd = 0;
 		    }
 		show_input(user, buf, p - buf);
@@ -533,7 +533,7 @@ ytalk_user(fd)
 	show_error("ytalk_user: unknown contact");
 	return;
     }
-    if(full_read(user->fd, &parm, sizeof(y_parm)) < 0)
+    if(full_read(user->fd, (char *)&parm, sizeof(y_parm)) < 0)
     {
 	free_user(user);
 	show_error("ytalk_user: bad ytalk contact");
@@ -621,7 +621,6 @@ connect_user(fd)
   int fd;
 {
     register yuser *user, *u;
-    unsigned int major, minor, patch;
 
     if((user = fd_to_user[fd]) == NULL)
     {
@@ -648,10 +647,8 @@ connect_user(fd)
     {
 	(void)memset(&parm, 0, sizeof(y_parm));
 	parm.protocol = YTP_NEW;
-	/* Get the version number */
-	sscanf(PACKAGE_VERSION, "%u.%u.%u", &major, &minor, &patch);
-	parm.vmajor = htons(major);
-	parm.vminor = htons(minor);
+	parm.vmajor = htons(VMAJOR);
+	parm.vminor = htons(VMINOR);
 	parm.rows = htons(me->t_rows);
 	parm.cols = htons(me->t_cols);
 	parm.my_rows = htons(user->t_rows);
@@ -693,7 +690,7 @@ contact_user(fd)
 {
     register yuser *user;
     register int n;
-    size_t socklen;
+    socklen_t socklen;
     struct sockaddr_in peer;
     char *hname;
 
@@ -712,7 +709,7 @@ contact_user(fd)
 	    show_error("connect_user: accept() failed");
 	return;
     }
-    close(fd);
+    (void)close(fd);
     fd_to_user[fd] = NULL;
 
     /* make sure the connection comes from the right place, else
@@ -723,10 +720,10 @@ contact_user(fd)
     {
         if (IN_ADDR(peer) != user->host_addr)
 	{
-	  if (user->host_name) 
-	      free(user->host_name);
-	  if (user->host_fqdn) 
-	      free(user->host_fqdn);
+	  if (user->host_name)
+	      free_mem(user->host_name);
+	  if (user->host_fqdn)
+	      free_mem(user->host_fqdn);
 	  user->host_addr = IN_ADDR(peer);
 	  hname = host_name(user->host_addr);
 	  user->host_name = str_copy(hname);
@@ -780,7 +777,7 @@ announce(user)
     {
 	/* he has an auto-invite port established */
 
-	if((fd = connect_to(NULL)) < 0)
+	if((fd = connect_to((yuser *)0)) < 0)
 	{
 	    if(fd == -3) /* it's one of my sockets... *sigh* */
 		break;
@@ -796,12 +793,12 @@ announce(user)
 	 * packet.
 	 */
 	v2p.code = V2_AUTO;
-	strncpy(v2p.name, me->user_name, V2_NAMELEN);
-	strncpy(v2p.host, me->host_name, V2_HOSTLEN);
+	(void)strncpy(v2p.name, me->user_name, V2_NAMELEN);
+	(void)strncpy(v2p.host, me->host_name, V2_HOSTLEN);
 	v2p.name[V2_NAMELEN-1] = '\0';
 	v2p.host[V2_HOSTLEN-1] = '\0';
 	(void)write(fd, &v2p, V2_PACKLEN);
-	close(fd);
+	(void)close(fd);
 	return 0;
     }
     if(rc == -1)
@@ -851,7 +848,7 @@ invite(name, send_announce)
 	}
     }
     user = new_user(hisname, hishost, histty);
-    free(hisname);
+    free_mem(hisname);
     if(user == NULL)
 	return NULL;
 
@@ -867,9 +864,9 @@ invite(name, send_announce)
 
     if (!dont_change_my_addr)
     {
-    	struct sockaddr_in tmpsock;
+	struct sockaddr_in tmpsock;
+	socklen_t i;
 	int sock;
-	unsigned int i;
 
 	sock = socket(PF_INET, SOCK_DGRAM, 0);
 
@@ -891,7 +888,7 @@ invite(name, send_announce)
 		    dont_change_my_addr++;
 		}
 	    }
-	    close(sock);
+	    (void)close(sock);
 	}
     }
 
@@ -934,7 +931,7 @@ invite(name, send_announce)
 
     if(send_announce)
     {
-	sprintf(errstr, "Ringing %s...", user->user_name);
+	(void)sprintf(errstr, "Ringing %s...", user->user_name);
 	msg_term(me, errstr);
     }
     if(newsock(user) != 0)
@@ -948,9 +945,9 @@ invite(name, send_announce)
     {
 	(void)send_dgram(user, DELETE_INVITE);
 	if(rc > 0)
-	    sprintf(errstr, "%s refusing messages", user->full_name);
+	    (void)sprintf(errstr, "%s refusing messages", user->full_name);
 	else
-	    sprintf(errstr, "%s not logged in", user->full_name);
+	    (void)sprintf(errstr, "%s not logged in", user->full_name);
 	show_error(errstr);
 	free_user(user);
 	return NULL;
@@ -995,7 +992,7 @@ house_clean()
 	    {
 		if(input_flag)
 		    continue;
-		sprintf(estr, "Rering %s?", u->full_name);
+		(void)sprintf(estr, "Rering %s?", u->full_name);
 		answer = yes_no(estr);
 		t = (ylong)time(NULL);
 		if(answer == 'n')
@@ -1005,9 +1002,9 @@ house_clean()
 	    {
 		(void)send_dgram(u, DELETE_INVITE);
 		if(rc > 0)
-		    sprintf(errstr, "%s refusing messages", u->full_name);
+		    (void)sprintf(errstr, "%s refusing messages", u->full_name);
 		else
-		    sprintf(errstr, "%s not logged in", u->full_name);
+		    (void)sprintf(errstr, "%s not logged in", u->full_name);
 		show_error(errstr);
 		free_user(u);
 	    }
@@ -1015,6 +1012,36 @@ house_clean()
     }
 }
 
+void
+rering_all()
+{
+    yuser *u, *next;
+    int rc;
+
+    if(send_auto(LEAVE_INVITE) != 0)
+    {
+	show_error("rering_all: send_auto() failed");
+	kill_auto();
+    }
+
+    for(u = wait_list; u; u = next)
+    {
+	next = u->next;
+	(void)send_dgram(u, LEAVE_INVITE);
+	u->last_invite = (ylong)time(NULL);
+	if((rc = announce(u)) != 0)
+	{
+	    (void)send_dgram(u, DELETE_INVITE);
+	    if(rc > 0)
+		(void)sprintf(errstr, "%s refusing messages", u->full_name);
+	    else
+		(void)sprintf(errstr, "%s not logged in", u->full_name);
+	    show_error(errstr);
+	    free_user(u);
+	}
+    }
+}
+
 void
 send_winch(user)
   yuser *user;
@@ -1126,141 +1153,7 @@ show_input(user, buf, len)
 process_esc:
 	for(; len > 0; len--, buf++)
 	{
-	    if(*buf >= '0' && *buf <= '9' && user->got_esc > 1)
-	    {
-		user->av[user->ac] = (user->av[user->ac] * 10) + (*buf - '0');
-		continue;
-	    }
-	    switch(*buf)
-	    {
-		case ';':	/* arg separator */
-		    if(user->ac < MAXARG-1)
-			user->av[++(user->ac)] = 0;
-		    break;
-		case '[':
-		    user->got_esc = 2;
-		    break;
-		case '?':
-		    if(user->got_esc == 2)
-			user->got_esc = 3;
-		    else
-			user->got_esc = 0;
-		    break;
-		case '7':	/* save cursor */
-		    user->sy = user->y;
-		    user->sx = user->x;
-		    user->got_esc = 0;
-		    break;
-		case '8':	/* restore cursor */
-		    move_term(user, user->sy, user->sx);
-		    user->got_esc = 0;
-		    break;
-		case '@':
-		    if(user->got_esc == 2)	/* add char */
-		    {
-			if(user->av[0] == 0)
-			    add_char_term(user, 1);
-			else
-			    add_char_term(user, user->av[0]);
-		    }
-		    user->got_esc = 0;
-		    break;
-		case 'A':	/* move up */
-		    if(user->av[0] == 0)
-			move_term(user, user->y - 1, user->x);
-		    else if(user->av[0] > user->y)
-			move_term(user, 0, user->x);
-		    else
-			move_term(user, user->y - user->av[0], user->x);
-		    user->got_esc = 0;
-		    break;
-		case 'B':	/* move down */
-		    if(user->av[0] == 0)
-			move_term(user, user->y + 1, user->x);
-		    else
-			move_term(user, user->y + user->av[0], user->x);
-		    user->got_esc = 0;
-		    break;
-		case 'C':	/* move right */
-		    if(user->av[0] == 0)
-			move_term(user, user->y, user->x + 1);
-		    else
-			move_term(user, user->y, user->x + user->av[0]);
-		    user->got_esc = 0;
-		    break;
-		case 'D':	/* move left */
-		    if(user->av[0] == 0)
-			move_term(user, user->y, user->x - 1);
-		    else if(user->av[0] > user->x)
-			move_term(user, user->y, 0);
-		    else
-			move_term(user, user->y, user->x - user->av[0]);
-		    user->got_esc = 0;
-		    break;
-		case 'H':	/* move */
-		    if(user->av[0] > 0)
-			user->av[0]--;
-		    if(user->av[1] > 0)
-			user->av[1]--;
-		    move_term(user, user->av[0], user->av[1]);
-		    user->got_esc = 0;
-		    break;
-		case 'J':	/* clear to end of screen */
-		    clreos_term(user);
-		    user->got_esc = 0;
-		    break;
-		case 'K':	/* clear to end of line */
-		    clreol_term(user);
-		    user->got_esc = 0;
-		    break;
-		case 'L':
-		    if(user->got_esc == 2)	/* add line */
-		    {
-			if(user->av[0] == 0)
-			    add_line_term(user, 1);
-			else
-			    add_line_term(user, user->av[0]);
-		    }
-		    user->got_esc = 0;
-		    break;
-		case 'M':
-		    if(user->got_esc == 2)	/* delete line */
-		    {
-			if(user->av[0] == 0)
-			    del_line_term(user, 1);
-			else
-			    del_line_term(user, user->av[0]);
-		    }
-		    else			/* reverse scroll */
-			rev_scroll_term(user);
-		    user->got_esc = 0;
-		    break;
-		case 'P':
-		    if(user->got_esc == 2)	/* del char */
-		    {
-			if(user->av[0] == 0)
-			    del_char_term(user, 1);
-			else
-			    del_char_term(user, user->av[0]);
-		    }
-		    user->got_esc = 0;
-		    break;
-		case 'S':	/* forward scroll */
-		    scroll_term(user);
-		    user->got_esc = 0;
-		    break;
-		case 'r':	/* set scroll region */
-		    if(user->av[0] > 0)
-			user->av[0]--;
-		    if(user->av[1] > 0)
-			user->av[1]--;
-		    set_scroll_region(user, user->av[0], user->av[1]);
-		    move_term(user, 0, 0);
-		    user->got_esc = 0;
-		    break;
-		default:
-		    user->got_esc = 0;
-	    }
+	    vt100_process(user, *buf);
 	    if(user->got_esc == 0)
 	    {
 		len--, buf++;
@@ -1306,7 +1199,8 @@ process_esc:
 	    switch(*buf)
 	    {
 		case 7:		/* Bell */
-		    putc(7, stderr);
+		    if(def_flags & FL_BEEP)
+			(void)putc(7, stderr);
 		    break;
 		case 8:		/* Backspace */
 		    if(user->x > 0)
@@ -1315,10 +1209,10 @@ process_esc:
 		case 9:		/* Tab */
 		    tab_term(user);
 		    break;
-		case 10:	/* Newline */
+		case 10:	/* Line Feed */
 		    newline_term(user);
 		    break;
-		case 13:	/* Return */
+		case 13:	/* Carriage Return */
 		    if(user->flags & FL_RAW)
 			move_term(user, user->y, 0);
 		    else
@@ -1400,10 +1294,10 @@ my_input(user, buf, len)
 		{
 		    if(*buf == me->old_rub || *buf == 8 || *buf == 0x7f)
 			*buf = me->RUB;
-		    else if(*buf == '\r')
-			*buf = '\n';
 		    else if(*buf == 3)	/* Ctrl-C */
 			bail(0);
+		    else if(*buf == '\r') /* CR */
+			*buf = '\n';
 		    else if(*buf == 27)	/* Esc */
 			break;
 		    else if(*buf == 12 || *buf == 18) /* ^L or ^R */
@@ -1412,7 +1306,10 @@ my_input(user, buf, len)
 		if((i = buf - c) > 0)
 		{
 		    if(user != NULL && user != me && !(def_flags & FL_ASIDE))
-			putc(7, stderr);
+		    {
+			if(def_flags & FL_BEEP)
+			    (void)putc(7, stderr);
+		    }
 		    else
 		    {
 			show_input(me, c, i);
