@@ -3,28 +3,30 @@
 /*			   NOTICE
  *
  * Copyright (c) 1990,1992,1993 Britt Yenne.  All rights reserved.
- * 
+ *
  * This software is provided AS-IS.  The author gives no warranty,
- * real or assumed, and takes no responsibility whatsoever for any 
+ * real or assumed, and takes no responsibility whatsoever for any
  * use or misuse of this software, or any damage created by its use
  * or misuse.
- * 
+ *
  * This software may be freely copied and distributed provided that
  * no part of this NOTICE is deleted or edited in any manner.
- * 
+ *
  */
 
-/* Mail comments or questions to metawire.org */
 
 #include "header.h"
+#include "mem.h"
 
-#if defined(HAVE_LIBNCURSES) && defined(HAVE_NCURSES_H)
+#ifdef HAVE_NCURSES_H
 # include <ncurses.h>
 #else
 # include <curses.h>
 #endif
 
-#include <sys/signal.h>
+/* Some systems, notably Solaris, don't have sys/signal.h */
+#include <signal.h>
+
 #include "cwin.h"
 
 typedef struct _ywin {
@@ -82,7 +84,6 @@ make_win(w, height, width, row, col)
 {
     if((w->win = newwin(height, width, row, col)) == NULL)
     {
-	register ywin *w;
 	w = (ywin *)(me->term);
 	if(w->win != NULL)
 	    show_error("make_win: newwin() failed");
@@ -132,6 +133,8 @@ static int
 win_size(wins)
   int wins;
 {
+    if(wins == 0)
+	return 0;
     return (LINES - 1) / wins;
 }
 
@@ -192,8 +195,12 @@ curses_redraw()
 static void
 curses_start()
 {
-    LINES = COLS = 0;	/* so resizes will work */
-    initscr();
+    char *term;
+    if (initscr() == NULL) {
+	term = getenv("TERM");
+	fprintf(stderr, "Error opening terminal: %s.\n", (term ? term : "(null)"));
+	bail(YTE_INIT);
+    }
     noraw();
     crmode();
     noecho();
@@ -276,7 +283,7 @@ open_curses(user, title)
 	wins++;
     if(win_size(wins+1) < 3)
 	return -1;
-    
+
     /* add the new user */
 
     if(head == NULL)
@@ -325,7 +332,8 @@ close_curses(user)
 	}
     }
     delwin(w->win);
-    free(w);
+    free_mem(w);
+    w = NULL;
     curses_redraw();
 }
 
@@ -399,6 +407,18 @@ scroll_curses(user)
     wmove(w->win, user->y, user->x);
 }
 
+#ifdef HAVE_KEYPAD
+void
+keypad_curses(user, bf)
+  yuser *user;
+  int bf;
+{
+    ywin *w;
+    w = (ywin *)(user->term);
+    keypad(w->win, bf);
+}
+#endif /* HAVE_KEYPAD */
+
 void
 flush_curses(user)
   register yuser *user;
