@@ -3,18 +3,17 @@
 /*			   NOTICE
  *
  * Copyright (c) 1990,1992,1993 Britt Yenne.  All rights reserved.
- * 
+ *
  * This software is provided AS-IS.  The author gives no warranty,
- * real or assumed, and takes no responsibility whatsoever for any 
+ * real or assumed, and takes no responsibility whatsoever for any
  * use or misuse of this software, or any damage created by its use
  * or misuse.
- * 
+ *
  * This software may be freely copied and distributed provided that
  * no part of this NOTICE is deleted or edited in any manner.
- * 
+ *
  */
 
-/* Mail comments or questions to metawire.org */
 
 extern void	init_curses	();
 extern void	end_curses	();
@@ -25,6 +24,7 @@ extern void	move_curses	( /* yuser, y, x */ );
 extern void	clreol_curses	( /* yuser */ );
 extern void	clreos_curses	( /* yuser */ );
 extern void	scroll_curses	( /* yuser */ );
+extern void	keypad_curses	( /* yuser, int */ );
 extern void	flush_curses	( /* yuser */ );
 extern void	redisplay_curses();
 extern void	set_raw_curses();
