@@ -3,18 +3,19 @@
 /*			   NOTICE
  *
  * Copyright (c) 1990,1992,1993 Britt Yenne.  All rights reserved.
- * 
+ *
  * This software is provided AS-IS.  The author gives no warranty,
- * real or assumed, and takes no responsibility whatsoever for any 
+ * real or assumed, and takes no responsibility whatsoever for any
  * use or misuse of this software, or any damage created by its use
  * or misuse.
- * 
+ *
  * This software may be freely copied and distributed provided that
  * no part of this NOTICE is deleted or edited in any manner.
- * 
+ *
  */
 
-/* Mail comments or questions to metawire.org */
+
+#include "config.h"
 
 #ifndef X_DISPLAY_MISSING
 # define USE_X11
@@ -22,19 +23,26 @@
 
 #include <sys/types.h>
 #include <sys/param.h>
-#include <sys/socket.h>
+
+#ifdef YTALK_HPUX
+# define _XOPEN_SOURCE_EXTENDED
+# include <sys/socket.h>
+# undef _XOPEN_SOURCE_EXTENDED
+#else
+# include <sys/socket.h>
+#endif
+
 #include <netinet/in.h>
 #include <errno.h>
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
 
-/* If grantpt/unlockpt/ptsname are available we still haven't got
-   prototypes. So we fix this here.                               */
+/* We may not have prototypes for these functions. */
 #if defined(HAVE_PTSNAME) && defined(HAVE_GRANTPT) && defined(HAVE_UNLOCKPT)
-extern int grantpt (int __fd);
-extern int unlockpt (int __fd);
-extern char *ptsname (int __fd);
+extern int grantpt (int);
+extern int unlockpt (int);
+extern char *ptsname (int);
 #endif
 
 #ifdef HAVE_UNISTD_H
@@ -45,6 +53,10 @@ extern char *ptsname (int __fd);
 # include <X11/X.h>
 #endif
 
+#define VMAJOR	3	/* major version number */
+#define VMINOR	1	/* minor version number */
+#define VPATCH	6	/* patch level */
+
 #define EIGHT_BIT_CLEAN /* take this one out if you don't want it */
 
 #ifdef EIGHT_BIT_CLEAN
@@ -77,6 +89,10 @@ typedef	u_int	ylong;		/* this should work both on 32-bit and 64-bit
 				 * machines  -Roger
 				 */
 
+#ifndef HAVE_SOCKLEN_T
+typedef int	socklen_t;
+#endif
+
 typedef struct {
     u_char w_rows, w_cols;	/* window size FOR PROTOCOL YTP_OLD */
     char protocol;		/* ytalk protocol -- see above */
@@ -101,6 +117,7 @@ typedef struct _yuser {
     u_short rows, cols;		/* his active region rows and cols over here */
     y_parm remote;		/* remote parms */
     ychar **scr;		/* screen data */
+    int *scr_tabs;		/* screen tab positions */
     char bump;			/* set if at far right */
     ychar old_rub;		/* my actual rub character */
     char got_esc;		/* received an ESC */
@@ -123,6 +140,7 @@ typedef struct _yuser {
     struct sockaddr_in orig_sock; /* original socket -- another sick hack */
     u_int av[MAXARG];		/* ESC sequence arguments */
     u_int ac;			/* ESC sequence arg count */
+    u_int lparen;		/* lparen escape? */
 
     /* out-of-band data */
 
@@ -132,12 +150,7 @@ typedef struct _yuser {
     void (*dfunc)();		/* function to call with drained data */
     int got_oob;		/* got OOB flag */
 
-#define DUMP_BUF_SIZE 4095
-    char dump_buf[DUMP_BUF_SIZE+1];
-    int dump_buf_len;
-    
-
-      /* anything below this is available for the terminal interface */
+    /* anything below this is available for the terminal interface */
 
     yterm term;			/* terminal cookie */
     int ty, tx;			/* terminal's idea of Y,X (optional) */
@@ -157,7 +170,9 @@ typedef struct _yuser {
 #define FL_CAPS		0x00000100L     /* want caps as answers */
 #define FL_NOAUTO       0x00000200L     /* no auto-invite port */
 #define FL_PROMPTRING	0x00000400L	/* prompt before reringing */
-#define FL_PROMPTQUIT	0x00000800L     /* prompt before quitting */
+#define FL_BEEP		0x00000800L	/* allow ytalk to beep? */
+#define FL_IGNBRK	0x00001000L	/* don't die when ^C is pressed */
+#define FL_PROMPTQUIT	0x00002000L	/* prompt before quitting */
 #define FL_LOCKED	0x40000000L	/* flags locked by other end */
 
 /* ---- defines and short-cuts ---- */
@@ -242,7 +257,7 @@ typedef struct {
 
 /* ---- exit codes ---- */
 
-#define YTE_SUCCESS_PROMPT -1	/* successful completion, prompt, return 0 */
+#define YTE_SUCCESS_PROMPT  -1	/* successful completion, prompt, return 0 */
 #define YTE_SUCCESS	0	/* successful completion */
 #define YTE_INIT	1	/* initialization error */
 #define YTE_NO_MEM	2	/* out of memory */
@@ -269,6 +284,7 @@ extern ychar *io_ptr;		/* user input pointer */
 extern int    io_len;		/* user input count */
 
 extern int running_process;	/* flag: is process running? */
+extern ylong myuid;		/* stores your uid */
 
 /* ---- some machine compatibility definitions ---- */
 
@@ -290,9 +306,7 @@ struct alias {
 /* ---- global functions ---- */
 
 extern void	bail		( /* int */ );			/* main.c */
-extern yaddr	get_mem		( /* int */ );			/* main.c */
 extern char    *str_copy	( /* string */ );		/* main.c */
-extern yaddr	realloc_mem	( /* pointer, int */ );		/* main.c */
 extern void	show_error	( /* str */ );			/* main.c */
 
 extern void	init_term	();				/* term.c */
@@ -319,6 +333,7 @@ extern void	del_line_term	( /* yuser, num */ );		/* term.c */
 extern void	add_char_term	( /* yuser, num */ );		/* term.c */
 extern void	del_char_term	( /* yuser, num */ );		/* term.c */
 extern void	redraw_term	( /* yuser, start_row */ );	/* term.c */
+extern void	keypad_term	( /* yuser, int */ );		/* term.c */
 extern void	resize_win	( /* yuser, h, w */ );		/* term.c */
 extern void	set_win_region	( /* yuser, h, w */ );		/* term.c */
 extern void	end_win_region	( /* yuser */ );		/* term.c */
@@ -336,6 +351,7 @@ extern yuser   *new_user	( /* name, host, tty */ );	/* user.c */
 extern void	free_user	( /* yuser */ );		/* user.c */
 extern yuser   *find_user	( /* name, host_addr, pid */ );	/* user.c */
 extern void	generate_full_name ( /* yuser */ );		/* user.c */
+extern void	free_users	();				/* user.c */
 
 extern void	init_fd		();				/* fd.c */
 extern void	add_fd		( /* fd, func */ );		/* fd.c */
@@ -355,6 +371,7 @@ extern void	show_input	( /* user, buf, len */ );	/* comm.c */
 extern void	my_input	( /* buf, len */ );		/* comm.c */
 extern void	lock_flags	( /* flags */ );		/* comm.c */
 extern void	unlock_flags	();				/* comm.c */
+extern void	rering_all	();				/* comm.c */
 
 extern void	init_socket	();				/* socket.c */
 extern void	close_all	();				/* socket.c */
@@ -375,9 +392,6 @@ extern void	update_exec	();				/* exec.c */
 extern void	kill_exec	();				/* exec.c */
 extern void	winch_exec	();				/* exec.c */
 
-extern void	set_file_dump	(char *fn);			/* log.c */
-extern void	addch_dump	(yuser *user, ychar c);		/* log.c */
-extern void	rub_dump	(yuser *user);			/* log.c */
-extern void	newline_dump	(yuser *user);			/* log.c */
+extern void	vt100_process	( /* yuser, char */ );		/* vt100.c */
 
 /* EOF */
