@@ -3,20 +3,20 @@
 /*			   NOTICE
  *
  * Copyright (c) 1990,1992,1993 Britt Yenne.  All rights reserved.
- * 
+ *
  * This software is provided AS-IS.  The author gives no warranty,
- * real or assumed, and takes no responsibility whatsoever for any 
+ * real or assumed, and takes no responsibility whatsoever for any
  * use or misuse of this software, or any damage created by its use
  * or misuse.
- * 
+ *
  * This software may be freely copied and distributed provided that
  * no part of this NOTICE is deleted or edited in any manner.
- * 
+ *
  */
 
-/* Mail comments or questions to metawire.org */
 
 #include "header.h"
+#include "mem.h"
 
 #ifdef HAVE_FCNTL_H
 #include <fcntl.h>
@@ -51,6 +51,7 @@ static menu_item main_menu[] = {
     { "delete a user",		main_menu_sel,	'd' },
     { "kill all unconnected",	main_menu_sel,  'k' },
     { "options",		main_menu_sel,	'o' },
+    { "rering all",		main_menu_sel,	'r' },
     { "shell",			main_menu_sel,	's' },
     { "user list",		main_menu_sel,	'u' },
     { "output user to file",	main_menu_sel,	'w' },
@@ -92,11 +93,12 @@ static menu_item error_menu[] = {
 /* ---- local functions ---- */
 
 static yuser *output_user = NULL;
-/*Output Function*/
-static void do_output(filename)
-char *filename;
+
+static void
+do_output(filename)
+  char *filename;
 {
-int fd;
+    int fd;
 
     if(output_user == NULL)
 	return;
@@ -109,8 +111,9 @@ int fd;
     spew_term(output_user, fd, output_user->rows, output_user->cols);
     output_user = NULL;
 }
-/*Output User Function */
-static void do_output_user(user)
+
+static void
+do_output_user(user)
   yuser *user;
 {
     /* if he has an open descriptor, close it */
@@ -132,16 +135,22 @@ static void do_output_user(user)
     else
 	output_user = NULL;
 }
-/*Invite User Function*/
-static void do_invite(name){
- invite(name, 1);
+
+static void
+do_invite(name)
+  char *name;
+{
+    invite(name, 1);
 }
-/*Kill All Conenctions*/
-static void kill_all_unconnected(){
-  while(wait_list) free_user(wait_list);
+
+static void
+kill_all_unconnected()
+{
+    while(wait_list) free_user(wait_list);
 }
-/*Menu Selection Function*/
-static void main_menu_sel(key)
+
+static void
+main_menu_sel(key)
   ychar key;
 {
     switch(key)
@@ -162,6 +171,10 @@ static void main_menu_sel(key)
 	    if(show_option_menu() >= 0)
 		update_menu();
 	    break;
+	case 'r':	/* rering all */
+	    rering_all();
+	    kill_menu();
+	    break;
 	case 's':	/* invoke a shell */
 	    kill_menu();
 	    execute(NULL);
@@ -178,8 +191,9 @@ static void main_menu_sel(key)
 	    bail(YTE_SUCCESS);
     }
 }
-/*Option  Menu Selection Function*/
-static void option_menu_sel(key)
+
+static void
+option_menu_sel(key)
   ychar key;
 {
     register yuser *u;
@@ -209,9 +223,9 @@ static void option_menu_sel(key)
 	case 'p':	/* toggle prompting before re-rings */
 	    def_flags ^= FL_PROMPTRING;
 	    break;
-	case 'q':       /* toggle prompting before quitting */
-	   def_flags ^= FL_PROMPTQUIT;
-	   break;
+	case 'q':	/* toggle prompting before quitting */
+	    def_flags ^= FL_PROMPTQUIT;
+	    break;
     }
 
     if(old_flags != def_flags)
@@ -227,8 +241,8 @@ static void option_menu_sel(key)
 	kill_menu();
 }
 
-/*User Menu Selection Function*/
-static void user_menu_sel(key)
+static void
+user_menu_sel(key)
   ychar key;
 {
     register int i;
@@ -242,8 +256,8 @@ static void user_menu_sel(key)
 	if(user_menu[i].key == key)
 	{
 	    for(u = user_list; u; u = u->unext)
-		if(u->key == key && 
- 		   strcmp(u->full_name, user_menu[i].item) == 0)
+		if(u->key == key &&
+		   strcmp(u->full_name, user_menu[i].item) == 0)
 		{
 		    user_menu[0].func(u);
 		    break;
@@ -256,18 +270,22 @@ static void user_menu_sel(key)
 
 #define MENU_EXTRA 7	/* number of extra characters per menu screen item */
 
-/*Generate Text Length*/
-static void generate_text_length(){
+static void
+generate_text_length()
+{
     menu_long = me->t_cols - MENU_EXTRA - 2;
     if(menu_long < 5 || menu_long > MAXTEXT)
 	menu_long = MAXTEXT;
 }
 
-/*Yes/No Length*/
-static void generate_yes_no_length(){
+static void
+generate_yes_no_length()
+{
     menu_long = strlen(yes_no_menu[0].item) - 2;
 }
-static void pad_str(from, len, to)
+
+static void
+pad_str(from, len, to)
   char *from, *to;
   int len;
 {
@@ -282,7 +300,9 @@ static void pad_str(from, len, to)
 
 /* End any menu processing.
  */
-void kill_menu(){
+void
+kill_menu()
+{
     register int i;
 
     if(menu_ptr != NULL)
@@ -316,7 +336,7 @@ update_menu()
 
     if(menu_ptr == NULL)
 	return;
-    
+
     /* process any input */
 
     if(io_len > 0)
@@ -331,7 +351,7 @@ update_menu()
 
 		if(ic > ' ' && ic <= '~')
 		{
-		    if(text_pos >= menu_long)
+		    if(text_pos >= menu_long && def_flags & FL_BEEP)
 			putc(7, stderr);
 		    else
 		    {
@@ -596,13 +616,13 @@ show_menu(menu, len)
     }
     if(menu_long < 10)
 	menu_long = 10;
-    
+
     /* set up the menu for display */
 
     menu_ptr = menu;
     menu_len = len;
     menu_line = 0;
-    
+
     return 0;
 }
 
@@ -637,7 +657,7 @@ show_text(prompt, func)
     text_xpos = -1;
     text_pos = 0;
     generate_text_length();
-    
+
     return 0;
 }
 
@@ -726,7 +746,7 @@ show_option_menu()
     i++;
 
     if(def_flags & FL_PROMPTRING)
-	option_menu[i].item = "don't prompt rerings";
+	option_menu[i].item = "don't prompt rerings   ";
     else
 	option_menu[i].item = "prompt before reringing";
     option_menu[i].func = option_menu_sel;
@@ -734,7 +754,7 @@ show_option_menu()
     i++;
 
     if(def_flags & FL_PROMPTQUIT)
-	option_menu[i].item = "don't prompt before quitting";
+	option_menu[i].item = "don't prompt to quit";
     else
 	option_menu[i].item = "prompt before quitting";
     option_menu[i].func = option_menu_sel;
@@ -784,7 +804,7 @@ show_user_menu(title, func, metoo)
 		i++;
 	    }
 	}
-    
+
     if(i > 2)
 	return show_menu(user_menu, i);
     kill_menu();
@@ -852,7 +872,7 @@ show_user_list()
 	user_menu[i].key = ' ';
 	i++;
     }
-    
+
     return show_menu(user_menu, i);
 }
 
