@@ -3,20 +3,21 @@
 /*			   NOTICE
  *
  * Copyright (c) 1990,1992,1993 Britt Yenne.  All rights reserved.
- * 
+ *
  * This software is provided AS-IS.  The author gives no warranty,
- * real or assumed, and takes no responsibility whatsoever for any 
+ * real or assumed, and takes no responsibility whatsoever for any
  * use or misuse of this software, or any damage created by its use
  * or misuse.
- * 
+ *
  * This software may be freely copied and distributed provided that
  * no part of this NOTICE is deleted or edited in any manner.
- * 
+ *
  */
 
-/* Mail comments or questions to metawire.org */
 
 #include "header.h"
+#include "mem.h"
+#include <pwd.h>
 
 #define IS_WHITE(c)	((c)==' ' || (c)=='\t' || (c)=='\n')
 
@@ -59,7 +60,7 @@ set_option(opt, value)
 	set_it = 0;
     else
 	return -1;
-    
+
     if(strcmp(opt, "scroll") == 0
     || strcmp(opt, "scrolling") == 0
     || strcmp(opt, "sc") == 0)
@@ -102,8 +103,15 @@ set_option(opt, value)
     else if(strcmp(opt, "prompt-quit") == 0
     || strcmp(opt, "promptquit") == 0
     || strcmp(opt, "pq") == 0)
-       mask |= FL_PROMPTQUIT;
+	mask |= FL_PROMPTQUIT;
 
+    else if(strcmp(opt, "beeps") == 0)
+	mask |= FL_BEEP;
+
+    else if(strcmp(opt, "ignorebreak") == 0)
+	mask |= FL_IGNBRK;
+
+#ifdef USE_X11
     else if(strcmp(opt, "xwin") == 0
     || strcmp(opt, "xwindows") == 0
     || strcmp(opt, "XWindows") == 0
@@ -111,12 +119,13 @@ set_option(opt, value)
     || strcmp(opt, "x") == 0
     || strcmp(opt, "X") == 0)
 	mask |= FL_XWIN;
+#endif
 
     else if(strcmp(opt, "asides") == 0
     || strcmp(opt, "aside") == 0
     || strcmp(opt, "as") == 0)
 	mask |= FL_ASIDE;
-    
+
     else if(strcmp(opt, "caps") == 0
     || strcmp(opt, "CAPS") == 0
     || strcmp(opt, "ca") == 0
@@ -150,8 +159,7 @@ read_rcfile(fname)
     int line_no, errline;
     struct alias *a;
 
-    if((fp = fopen(fname, "r")) == NULL)
-    {
+    if((fp = fopen(fname, "r")) == NULL) {
 	if(errno != ENOENT)
 	    show_error(fname);
 	return;
@@ -159,167 +167,150 @@ read_rcfile(fname)
     buf = get_mem(BUFSIZ);
 
     line_no = errline = 0;
-    while(fgets(buf, BUFSIZ, fp) != NULL)
-    {
+    while(fgets(buf, BUFSIZ, fp) != NULL) {
 	line_no++;
 	ptr = buf;
 	w = get_word(&ptr);
 	if(w == NULL || *w == '#')
 	    continue;
-	
-	if(strcmp(w, "readdress") == 0)
-	{
+
+	if(strcmp(w, "readdress") == 0) {
 	    arg1 = get_word(&ptr);
 	    arg2 = get_word(&ptr);
 	    arg3 = get_word(&ptr);
-	    if(arg3 == NULL)
-	    {
+	    if(arg3 == NULL) {
 		errline = line_no;
 		break;
 	    }
 	    readdress_host(arg1, arg2, arg3);
-	}
-	else if(strcmp(w, "set") == 0 || strcmp(w, "turn") == 0)
-	{
+	} else if(strcmp(w, "set") == 0 || strcmp(w, "turn") == 0) {
 	    arg1 = get_word(&ptr);
 	    arg2 = get_word(&ptr);
-	    if(arg2 == NULL)
-	    {
+	    if(arg2 == NULL) {
 		errline = line_no;
 		break;
 	    }
-	    if(set_option(arg1, arg2) < 0)
-	    {
+	    if(set_option(arg1, arg2) < 0) {
 		errline = line_no;
 		break;
 	    }
-	}
-	else if (strcmp(w, "localhost") == 0)
-	{
+	} else if (strcmp(w, "localhost") == 0) {
 	    arg1 = get_word(&ptr);
-	    if(arg1 == NULL)
-	    {
+	    if(arg1 == NULL) {
 		errline = line_no;
 		break;
 	    }
-	    if (vhost == NULL)
-	    {
+	    if (vhost == NULL) {
 		vhost = malloc(1+strlen(arg1));
 		if (vhost != NULL)
-		    strcpy(vhost, arg1);
+		    (void)strcpy(vhost, arg1);
 	    }
-	}
-	else if (strcmp(w, "alias") == 0)
-	{
+	} else if (strcmp(w, "alias") == 0) {
 	    arg1 = get_word(&ptr);
 	    arg2 = get_word(&ptr);
-	    if(arg2 == NULL)
-	    {
+	    if(arg2 == NULL) {
 		errline = line_no;
 		break;
 	    }
 	    a = get_mem(sizeof (struct alias));
 	    at = strchr(arg1, '@');
 	    if (at == arg1) {
-	      a->type = ALIAS_AFTER;
-	      strncpy(a->from, arg1+1, 255);
-	      a->from[254] = 0;
-	      strncpy(a->to, (*arg2=='@' ? arg2+1 : arg2), 255);
-	      a->to[254] = 0;
+		a->type = ALIAS_AFTER;
+		(void)strncpy(a->from, arg1+1, 255);
+		a->from[254] = 0;
+		(void)strncpy(a->to, (*arg2=='@' ? arg2+1 : arg2), 255);
+		a->to[254] = 0;
 	    } else if (at == arg1 + strlen(arg1) - 1) {
-	      a->type = ALIAS_BEFORE;
-	      *at = 0;
-	      strncpy(a->from, arg1, 255);
-	      a->from[254] = 0;
-	      strncpy(a->to, arg2, 255);
-	      a->to[254] = 0;
-	      if ((at = strchr(a->to, '@')) != NULL)
+		a->type = ALIAS_BEFORE;
+		*at = 0;
+		(void)strncpy(a->from, arg1, 255);
+		a->from[254] = 0;
+		(void)strncpy(a->to, arg2, 255);
+		a->to[254] = 0;
+		if ((at = strchr(a->to, '@')) != NULL)
 		*at = 0;
 	    } else {
-	      a->type = ALIAS_ALL;
-	      strncpy(a->from, arg1, 255);
-	      a->from[254] = 0;
-	      strncpy(a->to, arg2, 255);
-	      a->to[254] = 0;
+		a->type = ALIAS_ALL;
+		(void)strncpy(a->from, arg1, 255);
+		a->from[254] = 0;
+		(void)strncpy(a->to, arg2, 255);
+		a->to[254] = 0;
 	    }
 	    a->next = alias0;
 	    alias0 = a;
-	}
-	else
-	{
+	} else {
 	    errline = line_no;
 	    break;
 	}
     }
-    if(errline)
-    {
-	sprintf(errstr, "%s: syntax error at line %d", fname, errline);
+    if(errline) {
+	(void)sprintf(errstr, "%s: syntax error at line %d", fname, errline);
 	errno = 0;
 	show_error(errstr);
     }
 
-    free(buf);
-    fclose(fp);
+    free_mem(buf);
+    (void)fclose(fp);
 }
 
 /* ---- global functions ---- */
 
 char *
-resolve_alias(uh) 
+resolve_alias(uh)
   char *uh;
 {
-  struct alias *a;
-  static char uh1[256], *at;
-  int found = 0;
+    struct alias *a;
+    static char uh1[256], *at;
+    int found = 0;
 
-  for (a=alias0; a; a=a->next)
-    if (a->type == ALIAS_ALL && strcmp(uh, a->from) == 0)
-      return a->to;
+    for (a=alias0; a; a=a->next)
+	if (a->type == ALIAS_ALL && strcmp(uh, a->from) == 0)
+	    return a->to;
 
-  strncpy(uh1, uh, 255);
-  uh1[254] = 0;
-  if ((at = strchr(uh1, '@')) != NULL)
-    *at = 0;
-  for (a=alias0; a; a=a->next) {
-    if (a->type == ALIAS_BEFORE && strcmp(uh1, a->from) == 0) {
-      found = 1;
-      strncpy(uh1, a->to, 255);
-      uh1[254] = 0;
-      if ((at = strchr(uh, '@')) != NULL)
-        if (strlen(uh1) + strlen(at) < 256)
-          strcat(uh1, at);
-      uh = uh1;
-      break;
-    }
-  }
-  if (!found) {
-    strncpy(uh1, uh, 255);
+    (void)strncpy(uh1, uh, 255);
     uh1[254] = 0;
-  }
-  at = strchr(uh1, '@');
-  if (at && at[1]) {
-    at++;
+    if ((at = strchr(uh1, '@')) != NULL)
+	*at = 0;
     for (a=alias0; a; a=a->next) {
-      if (a->type == ALIAS_AFTER && strcmp(at, a->from) == 0) {
-        found = 1;
-        if (strlen(a->to) + (at - uh1) < 255)
-          strcpy(at, a->to);
-        break;
-      }
+	if (a->type == ALIAS_BEFORE && strcmp(uh1, a->from) == 0) {
+	    found = 1;
+	    (void)strncpy(uh1, a->to, 255);
+	    uh1[254] = 0;
+	    if ((at = strchr(uh, '@')) != NULL)
+		if (strlen(uh1) + strlen(at) < 256)
+		    (void)strcat(uh1, at);
+		uh = uh1;
+		break;
+	    }
+	}
+    if (!found) {
+	(void)strncpy(uh1, uh, 255);
+	uh1[254] = 0;
     }
-  }
-  if (found)
-    return uh1;
-  else
-    return uh;
+    at = strchr(uh1, '@');
+    if (at && at[1]) {
+	at++;
+	for (a=alias0; a; a=a->next) {
+	    if (a->type == ALIAS_AFTER && strcmp(at, a->from) == 0) {
+		found = 1;
+		if (strlen(a->to) + (at - uh1) < 255)
+		    (void)strcpy(at, a->to);
+		break;
+	    }
+	}
+    }
+    if (found)
+	return uh1;
+    else
+	return uh;
 }
 
 void
 read_ytalkrc()
 {
-    char *w;
     yuser *u;
-    char fname[256];
+    char *fname;
+    struct passwd *pw;
 
     /* read the system ytalkrc file */
 
@@ -329,19 +320,13 @@ read_ytalkrc()
 
     /* read the user's ytalkrc file */
 
-    if((w = (char *)getenv("HOME")) != NULL)
+    pw = getpwuid(myuid);
+    if(pw != NULL)
     {
-	if(strlen(w) > 246) /* Exceeds fixed length buffer */
-	{
-	    fprintf(stderr, "read_ytalkrc: Cannot read ~/.ytalkrc "
-	                    "as HOME is too long\n");
-	    sleep(1);
-	}
-	else
-	{
-	    snprintf(fname, 256, "%s/.ytalkrc", w);
-	    read_rcfile(fname);
-	}
+	fname = get_mem((strlen(pw->pw_dir) + 10) * sizeof(char));
+	(void)sprintf(fname, "%s/.ytalkrc", pw->pw_dir);
+	read_rcfile(fname);
+	free_mem(fname);
     }
 
     /* set all default flags */
