@@ -3,22 +3,22 @@
 /*			   NOTICE
  *
  * Copyright (c) 1990,1992,1993 Britt Yenne.  All rights reserved.
- * 
+ *
  * This software is provided AS-IS.  The author gives no warranty,
- * real or assumed, and takes no responsibility whatsoever for any 
+ * real or assumed, and takes no responsibility whatsoever for any
  * use or misuse of this software, or any damage created by its use
  * or misuse.
- * 
+ *
  * This software may be freely copied and distributed provided that
  * no part of this NOTICE is deleted or edited in any manner.
- * 
+ *
  */
 
-/* Mail comments or questions to metawire.org */
 
 #include "header.h"
 #include "menu.h"
 #include "socket.h"
+#include "mem.h"
 
 #ifdef TIME_WITH_SYS_TIME
 # include <sys/time.h>
@@ -31,6 +31,13 @@
 # endif
 #endif
 
+#ifdef HAVE_ARPA_INET_H
+# include <arpa/inet.h>
+#else
+ylong inet_addr();
+char *inet_ntoa();
+#endif
+
 #ifdef _AIX
 # include <sys/select.h>
 #endif
@@ -63,7 +70,7 @@ init_dgram(sock)
   struct sockaddr_in *sock;
 {
     int fd;
-    size_t socklen;
+    socklen_t socklen;
 
     sock->sin_family = AF_INET;
     IN_ADDR(*sock) = INADDR_ANY;
@@ -113,7 +120,7 @@ init_daemon(name, port, mptr, mlen, rptr, rlen)
 	talkd[d].port = serv->s_port;
     else
 	talkd[d].port = port;
-    
+
     talkd[d].fd = init_dgram(&(talkd[d].sock));
     talkd[d].mptr = mptr;
     talkd[d].mlen = mlen;
@@ -126,7 +133,7 @@ static void
 read_autoport(fd)
   int fd;
 {
-    size_t socklen;
+    socklen_t socklen;
     static v2_pack pack;
     static char estr[V2_NAMELEN + V2_HOSTLEN + 20];
     static struct sockaddr_in temp;
@@ -144,13 +151,18 @@ read_autoport(fd)
      * packet.
      */
     errno = 0;
-    if(full_read(fd, &pack, V2_PACKLEN) < 0 || pack.code != V2_AUTO)
+    if(full_read(fd, (char *)&pack, V2_PACKLEN) < 0 || pack.code != V2_AUTO)
     {
 	show_error("read_autoport: unknown auto-invite connection");
 	close(fd);
 	return;
     }
     close(fd);
+
+    /* Disarm a remote %s overflow vulnerability. */
+    pack.name[V2_NAMELEN - 1] = '\0';
+    pack.host[V2_NAMELEN - 1] = '\0';
+
     if(!(def_flags & FL_INVITE))
     {
 	sprintf(estr, "Talk to %s@%s?", pack.name, pack.host);
@@ -158,7 +170,7 @@ read_autoport(fd)
 	    return;
     }
     sprintf(estr, "%s@%s", pack.name, pack.host);
-    invite(estr, 1);	/* we should be expected */
+    (void)invite(estr, 1);	/* we should be expected */
 }
 
 /* Create and initialize the auto-invitation socket.
@@ -166,7 +178,7 @@ read_autoport(fd)
 static void
 init_autoport()
 {
-    size_t socklen;
+    socklen_t socklen;
 
     autosock.sin_family = AF_INET;
     IN_ADDR(autosock) = INADDR_ANY;
@@ -238,7 +250,7 @@ sendit(addr, d)
   int d;	/* daemon number */
 {
     int n;
-    struct sockaddr_in daemon;
+    struct sockaddr_in remote_daemon;
     struct timeval tv;
     char *rtype, *mtype;
     fd_set sel;
@@ -274,9 +286,9 @@ sendit(addr, d)
 
     /* set up a sockaddr_in for the daemon we're sending to */
 
-    daemon.sin_family = AF_INET;
-    IN_ADDR(daemon) = addr;
-    IN_PORT(daemon) = talkd[d].port;
+    remote_daemon.sin_family = AF_INET;
+    IN_ADDR(remote_daemon) = addr;
+    IN_PORT(remote_daemon) = talkd[d].port;
 
     /* flush any lingering input */
 
@@ -308,10 +320,10 @@ sendit(addr, d)
      */
     do
     {
-    	do
+	do
 	{
 	    n = sendto(talkd[d].fd, (char *)talkd[d].mptr, talkd[d].mlen,
-		0, (struct sockaddr *) &daemon, sizeof(daemon));
+		0, (struct sockaddr *) &remote_daemon, sizeof(remote_daemon));
 	    if(n != talkd[d].mlen)
 	    {
 		show_error("sendit: sendto() failed");
@@ -326,9 +338,9 @@ sendit(addr, d)
 		show_error("sendit: first select() failed");
 		return -1;
 	    }
- 	} while (n <= 0);	/* ie: until we receive a reply */
+	} while (n <= 0);	/* ie: until we receive a reply */
 
-    	do
+	do
 	{
 	    n = recv(talkd[d].fd, talkd[d].rptr, talkd[d].rlen, 0);
 	    if(n < 0)
@@ -348,7 +360,7 @@ sendit(addr, d)
 		show_error("sendit: second select() failed");
 		return -1;
 	    }
-    	} while(n > 0 && *rtype != *mtype);
+	} while(n > 0 && *rtype != *mtype);
     } while(*rtype != *mtype);
 
     /* WHEW */
@@ -399,7 +411,7 @@ find_daemon(addr)
     register int n, i, d;
     CTL_MSG m1;
     CTL_MSG42 m2;
-    struct sockaddr_in daemon;
+    struct sockaddr_in remote_daemon;
     struct timeval tv;
     int out, max;
     fd_set sel;
@@ -412,8 +424,8 @@ find_daemon(addr)
 	if(h->host_addr == addr)
 	    return h->dtype;
 
-    daemon.sin_family = AF_INET;
-    IN_ADDR(daemon) = addr;
+    remote_daemon.sin_family = AF_INET;
+    IN_ADDR(remote_daemon) = addr;
 
     m1 = omsg;
     m2 = nmsg;
@@ -434,15 +446,15 @@ find_daemon(addr)
     out = 0;
     for(i = 0; i < 5; i++)
     {
-	IN_PORT(daemon) = talkd[ntalk].port;
+	IN_PORT(remote_daemon) = talkd[ntalk].port;
 	n = sendto(talkd[ntalk].fd, (char *)&m2, sizeof(m2),
-	    0, (struct sockaddr *) &daemon, sizeof(daemon));
+	    0, (struct sockaddr *) &remote_daemon, sizeof(remote_daemon));
 	if(n != sizeof(m2))
 	    show_error("Warning: cannot write to new talk daemon");
 
-	IN_PORT(daemon) = talkd[otalk].port;
+	IN_PORT(remote_daemon) = talkd[otalk].port;
 	n = sendto(talkd[otalk].fd, (char *)&m1, sizeof(m1),
-	    0, (struct sockaddr *) &daemon, sizeof(daemon));
+	    0, (struct sockaddr *) &remote_daemon, sizeof(remote_daemon));
 	if(n != sizeof(m1))
 	    show_error("Warning: cannot write to old talk daemon");
 
@@ -473,7 +485,7 @@ find_daemon(addr)
 
 		    r = recv(talkd[d].fd, errstr, talkd[d].rlen, 0);
 		    if (r < 0) {
-		    	if (errno == EINTR || errno == ECONNREFUSED)
+			if (errno == EINTR || errno == ECONNREFUSED)
 			    continue;
 			else
 			    show_error("find_daemon: recv() failed");
@@ -496,7 +508,7 @@ find_daemon(addr)
 	h->host_addr = addr;
 	h->dtype = out;
 	if (out)
-		return out;
+	    return out;
     }
     sprintf(errstr, "No talk daemon on %s", host_name(addr));
     show_error(errstr);
@@ -777,7 +789,7 @@ newsock(user)
   yuser *user;
 {
     int fd;
-    size_t socklen;
+    socklen_t socklen;
 
     user->sock.sin_family = AF_INET;
     IN_ADDR(user->sock) = INADDR_ANY;
@@ -800,7 +812,7 @@ newsock(user)
 	show_error("newsock: getsockname() failed");
 	return -1;
     }
-    place_my_address(&(user->sock), user->host_addr);
+    place_my_address((BSD42_SOCK *)&(user->sock), user->host_addr);
     if(listen(fd, 5) < 0)
     {
 	close(fd);
@@ -821,7 +833,7 @@ connect_to(user)
 {
     register yuser *u;
     int fd;
-    size_t socklen;
+    socklen_t socklen;
     struct sockaddr_in sock, orig_sock;
 
     orig_sock = *(struct sockaddr_in *)&nrsp.addr;
@@ -876,7 +888,6 @@ get_host_addr(hostname)
 {
     struct hostent *host;
     ylong addr;
-    ylong inet_addr();
 
     errno = 0;
     if((host = (struct hostent *) gethostbyname(hostname)) != NULL)
@@ -902,7 +913,6 @@ host_name(addr)
   ylong addr;
 {
     struct hostent *host;
-    char *inet_ntoa();
     char **s;
 
     if((host = gethostbyaddr((char *) &addr, sizeof(addr), AF_INET)) == NULL)
@@ -955,7 +965,7 @@ readdress_host(from_id, to_id, on_id)
     from_mask = make_net_mask(from_addr);
     to_mask = make_net_mask(to_addr);
     on_mask = make_net_mask(on_addr);
-    
+
 #if 0
     if((from_addr & from_mask) != (me->host_addr & from_mask))
 	return;
