@@ -1,20 +1,4 @@
-/* socket.h - socket functions (socket.c) */
-
-/*                       NOTICE
- *
- * Copyright (c) 1990,1992,1993 Britt Yenne.  All rights reserved.
- * 
- * This software is provided AS-IS.  The author gives no warranty,
- * real or assumed, and takes no responsibility whatsoever for any 
- * use or misuse of this software, or any damage created by its use
- * or misuse.
- * 
- * This software may be freely copied and distributed provided that
- * no part of this NOTICE is deleted or edited in any manner.
- * 
- */
-
-/* Mail comments or questions to metawire.org */
+/* socket.h */
 
 #include <netdb.h>
 
@@ -40,10 +24,10 @@ typedef struct _hostinfo {
 
 typedef struct _readdr {
     struct _readdr *next;	/* next in linked list */
-    ylong from_addr;	/* does this apply to me? */
+    ylong from_addr;		/* does this apply to me? */
     ylong from_mask;
-    ylong addr;		/* this net address [group?], */
-    ylong mask;		/* with this mask, */
+    ylong addr;			/* this net address [group?], */
+    ylong mask;			/* with this mask, */
     ylong id_addr;		/* thinks I'm at this net address, */
     ylong id_mask;		/* with this mask. */
 } readdr;
@@ -53,9 +37,7 @@ extern int daemons;
 
 /* ---- talk daemon I/O structures ---- */
 
-/* "New" protocol definies 12 as the correct length instead of 9
-   - supporting usernames with a length <= 11 */
-#define NAME_SIZE 12
+#define NAME_SIZE 9
 #define TTY_SIZE 16
 
 typedef struct bsd42_sockaddr_in {
@@ -100,9 +82,9 @@ typedef struct {
 	BSD42_SOCK	ctl_addr;
 	ylong	pid;
 	char	l_name[NAME_SIZE];
-/*	char	l_name_filler[3]; - these are obsoleted by a longer username */
+	char	l_name_filler[3];
 	char	r_name[NAME_SIZE];
-/*	char	r_name_filler[3]; - -"- */
+	char	r_name_filler[3];
 	char	r_tty[TTY_SIZE];
 } CTL_MSG42;
 
@@ -117,7 +99,7 @@ typedef struct {
 	BSD42_SOCK	addr;
 } CTL_RESPONSE42;
 
-#define	TALK_VERSION	1		/* protocol version */
+#define	TALK_VERSION	1	/* protocol version */
 
 /* Dgram Types.
  *
