@@ -3,20 +3,20 @@
 /*			   NOTICE
  *
  * Copyright (c) 1990,1992,1993 Britt Yenne.  All rights reserved.
- * 
+ *
  * This software is provided AS-IS.  The author gives no warranty,
- * real or assumed, and takes no responsibility whatsoever for any 
+ * real or assumed, and takes no responsibility whatsoever for any
  * use or misuse of this software, or any damage created by its use
  * or misuse.
- * 
+ *
  * This software may be freely copied and distributed provided that
  * no part of this NOTICE is deleted or edited in any manner.
- * 
+ *
  */
 
-/* Mail comments or questions to metawire.org */
 
 #include "header.h"
+#include "mem.h"
 
 #ifdef HAVE_SYS_IOCTL_H
 # include <sys/ioctl.h>
@@ -161,7 +161,7 @@ init_term()
 #endif
 
     /* if no window system found, default to curses */
-     
+
     if(term_type == 0)
     {
 	_open_term = open_curses;
@@ -179,7 +179,7 @@ init_term()
 
     /* set me up a terminal */
 
-    sprintf(tmpstr, "YTalk version %s", PACKAGE_VERSION);
+    (void)sprintf(tmpstr, "YTalk version %d.%d.%d", VMAJOR, VMINOR, VPATCH);
     if(open_term(me, tmpstr) < 0)
     {
 	end_term();
@@ -199,7 +199,7 @@ set_terminal_size(fd, rows, cols)
 
     winsize.ws_row = rows;
     winsize.ws_col = cols;
-    ioctl(fd, TIOCSWINSZ, &winsize);
+    (void)ioctl(fd, TIOCSWINSZ, &winsize);
 #endif
 }
 
@@ -227,6 +227,21 @@ what_term()
     return term_type;
 }
 
+#ifdef HAVE_KEYPAD
+/* Change terminal keypad mode (only for me, only with curses)
+ */
+void
+keypad_term(user, bf)
+  yuser *user;
+  int bf;
+{
+    if(user != me)
+	return;
+    if(term_type == 1)
+	keypad_curses(user, bf);
+}
+#endif /* HAVE_KEYPAD */
+
 /* Abort all terminal processing.
  */
 void
@@ -273,9 +288,11 @@ close_term(user)
     {
 	_close_term(user);
 	for(i = 0; i < user->t_rows; i++)
-	    free(user->scr[i]);
-	free(user->scr);
+	    free_mem(user->scr[i]);
+	free_mem(user->scr);
 	user->scr = NULL;
+	free_mem(user->scr_tabs);
+	user->scr_tabs = NULL;
 	user->t_rows = user->rows = 0;
 	user->t_cols = user->cols = 0;
     }
@@ -290,7 +307,6 @@ addch_term(user, c)
 {
     if (is_printable(c))
     {
-        addch_dump(user,c);
 	_addch_term(user, c);
 	user->scr[user->y][user->x] = c;
 	if(++(user->x) >= user->cols)
@@ -490,7 +506,7 @@ rub_term(user)
 	    addch_term(user, ' ');
 	    move_term(user, user->y, user->x - 1);
 	}
-       rub_dump(user);
+
     }
 }
 
@@ -533,7 +549,16 @@ void
 tab_term(user)
   register yuser *user;
 {
-    move_term(user, user->y, (user->x + 8) & 0xfff8);
+    int i;
+    /* Find nearest tab and jump to it. */
+    if(user->x < user->t_cols) {
+	for(i=(user->x+1);i<=user->t_cols;i++) {
+	    if(user->scr_tabs[i] == 1) {
+		move_term(user, user->y, i);
+		break;
+	    }
+	}
+    }
 }
 
 /* Process a newline.
@@ -543,7 +568,6 @@ newline_term(user)
   register yuser *user;
 {
     register int new_y, next_y;
-    newline_dump(user);
 
     new_y = user->y + 1;
     if(user->flags & FL_RAW)
@@ -739,8 +763,6 @@ del_char_term(user, num)
     register ychar *c;
     register int i;
 
-    printf("num=%d\n",num);
-
     /* find number of remaining non-blank chars */
 
     i = user->cols - user->x - num;
@@ -860,7 +882,7 @@ resize_win(user, height, width)
   int height, width;
 {
     register int j, i;
-    register ychar *c, **newscr;
+    register ychar *c, **new_scr;
     int new_y, y_pos;
 
     if(height == user->t_rows && width == user->t_cols)
@@ -870,7 +892,7 @@ resize_win(user, height, width)
 
     new_y = -1;
     y_pos = 0;
-    newscr = (ychar **)get_mem(height * sizeof(ychar *));
+    new_scr = (ychar **)get_mem(height * sizeof(ychar *));
     if(user->scr == NULL)
     {
 	user->t_rows = user->rows = 0;
@@ -881,12 +903,12 @@ resize_win(user, height, width)
 	/* save as many top lines as possible */
 
 	for(j = 0; j < height && j < user->t_rows; j++)
-	    newscr[j] = user->scr[j];
+	    new_scr[j] = user->scr[j];
 	new_y = j - 1;
 	y_pos = user->y;
 	for(; j < user->t_rows; j++)
-	    free(user->scr[j]);
-	free(user->scr);
+	    free_mem(user->scr[j]);
+	free_mem(user->scr);
     }
     else
     {
@@ -895,7 +917,7 @@ resize_win(user, height, width)
 	j = first_interesting_row(user, height, width);
 	for(i = 0; i < height; i++)
 	{
-	    newscr[++new_y] = user->scr[j];
+	    new_scr[++new_y] = user->scr[j];
 	    if(j == user->y)
 		break;
 	    if(++j >= user->t_rows)
@@ -905,22 +927,33 @@ resize_win(user, height, width)
 	{
 	    if(++j >= user->t_rows)
 		j = 0;
-	    free(user->scr[j]);
+	    free_mem(user->scr[j]);
 	}
 	y_pos = new_y;
-	free(user->scr);
+	free_mem(user->scr);
     }
-    user->scr = newscr;
+    user->scr = new_scr;
 
     /* fill in the missing portions */
 
-    if(width > user->t_cols)
+    if(width > user->t_cols) {
 	for(i = 0; i <= new_y; i++)
 	{
 	    user->scr[i] = (ychar *)realloc_mem(user->scr[i], width);
 	    for(j = user->t_cols; j < width; j++)
 		user->scr[i][j] = ' ';
 	}
+
+	user->scr_tabs = realloc_mem(user->scr_tabs, width * sizeof(int));
+	for(j = user->t_cols; j < width; j++) {
+	    if(j % 8 == 0)
+		user->scr_tabs[j] = 1;
+	    else
+		user->scr_tabs[j] = 0;
+	}
+	/* rightmost column is always last tab on line */
+	user->scr_tabs[width - 1] = 1;
+    }
     for(i = new_y + 1; i < height; i++)
     {
 	c = user->scr[i] = (ychar *)get_mem(width);
@@ -938,6 +971,9 @@ resize_win(user, height, width)
     send_winch(user);
     redraw_term(user, 0);
     flush_term(user);
+
+    /* Restore raw mode if running a shell */
+    if(running_process) set_raw_term();
 }
 
 /* Draw a nice box.
@@ -1025,7 +1061,7 @@ set_win_region(user, height, width)
     user->sc_bot = height - 1;
     move_term(user, y, x);
     flush_term(user);
-    
+
     if(user == me)
 	send_region();
 }
@@ -1124,7 +1160,7 @@ spew_term(user, fd, rows, cols)
 
 	/* move the cursor to the correct place */
 
-	sprintf(tmp, "%c[%d;%dH", 27, user->y + 1, user->x + 1);
+	(void)sprintf(tmp, "%c[%d;%dH", 27, user->y + 1, user->x + 1);
 	(void)write(fd, tmp, strlen(tmp));
     }
     else
