@@ -3,23 +3,23 @@
 /*			   NOTICE
  *
  * Copyright (c) 1990,1992,1993 Britt Yenne.  All rights reserved.
- * 
+ *
  * This software is provided AS-IS.  The author gives no warranty,
- * real or assumed, and takes no responsibility whatsoever for any 
+ * real or assumed, and takes no responsibility whatsoever for any
  * use or misuse of this software, or any damage created by its use
  * or misuse.
- * 
+ *
  * This software may be freely copied and distributed provided that
  * no part of this NOTICE is deleted or edited in any manner.
- * 
+ *
  */
 
-/* Mail comments or questions to metawire.org */
 
 #include "header.h"
 
 #ifdef USE_X11
 
+#include "mem.h"
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/Xresource.h>
@@ -106,7 +106,7 @@ make_GC(gc, font, fgpixel, bgpixel, l_width, l_style, l_cap, l_join, gcfunc)
     values.line_style = l_style;
     values.cap_style = l_cap;
     values.join_style = l_join;
-    mask |= GCForeground | GCBackground | GCLineWidth | GCLineStyle | 
+    mask |= GCForeground | GCBackground | GCLineWidth | GCLineStyle |
 	    GCCapStyle | GCJoinStyle;
     if(gcfunc != -1)
     {
@@ -338,7 +338,7 @@ addch_xwin(user, ch)
 	False);
     XDrawString(display, user->win, textGC,
 	XPOS(user->tx), YPOS(user->ty) + font_ascent,
-	&ch, 1);
+	(char *)&ch, 1);
     user->tx++;
     if(user->tx >= user->t_cols)
 	user->tx--;
@@ -418,7 +418,7 @@ void
 flush_xwin(user)
   yuser *user;
 {
-    /* "user" is unused -- sorry, lint  :-) */
+    (void)user;
     XFlush(display);
 }
 
